==> cms_content_sync-8.x-1.9.tar.gz: cms_content_sync/src/SyncCorePoolExport.php <==
<?php

namespace Drupal\cms_content_sync;

use Drupal\cms_content_sync\Entity\Pool;
use Drupal\cms_content_sync\Form\PoolForm;

/**
 *
 */
class SyncCorePoolExport extends SyncCoreExport {

  /**
   * @var string META_ENTITY_CONNECTION_PATH
   *   The path at which the meta information per entity for each remote site
   *   can be found. This allows to query the usage of an entity on other sites.
   */
  const META_ENTITY_CONNECTION_PATH = '/api_unify-api_unify-entity_meta_information_connection-0_1';

  /**
   * @var string POOL_SITE_ID
   *   The virtual site id for the pool and it's connections / synchronizations.
   */
  const POOL_SITE_ID = '_pool';

  /**
   * @var string EXTERNAL_PREVIEW_PATH
   *   The path to find the preview entities at.
   */
  const EXTERNAL_PREVIEW_PATH = 'drupal/cms-content-sync/preview';

  /**
   * @var string CUSTOM_API_VERSION
   *   The API version used to identify APIs as. Breaking changes in
   *   Flow will require this version to be increased and all
   *   synchronization entities to be re-saved via update hook.
   */
  const CUSTOM_API_VERSION = '1.0';

  /**
   * @var \Drupal\cms_content_sync\Entity\Pool
   */
  protected $pool;

  /**
   * SyncCorePoolExport constructor.
   *
   * @param \Drupal\cms_content_sync\Entity\Pool $pool
   *   The pool this exporter is used for.
   */
  public function __construct(Pool $pool) {
    parent::__construct();

    $this->pool = $pool;
  }

  /**
   * Get the absolute URL that Sync Core should use to create, update or delete
   * an entity.
   *
   * @param string $api_id
   * @param string $entity_type_name
   * @param string $bundle_name
   * @param string $version
   * @param string $entity_uuid
   *
   * @return string
   */
  public static function getInternalUrl($api_id, $entity_type_name, $bundle_name, $version, $entity_uuid = NULL) {
    $export_url = static::getBaseUrl();

    $url = sprintf('%s/rest/cms-content-sync/%s/%s/%s/%s',
      $export_url,
      $api_id,
      $entity_type_name,
      $bundle_name,
      $version
    );
    if ($entity_uuid) {
      $url .= '/' . $entity_uuid;
    }
    $url .= '?_format=json&is_dependency=[is_dependency]&is_manual=[is_manual]';
    return $url;
  }

  /**
   * Check if another site has already connected to this pool with the same
   * site ID.
   */
  public function siteIdExists() {
    $url = $this->pool->getBackendUrl();

    $condition = [
      "operator" => "and",
      "conditions" => [
        [
          "operator" => "==",
          "values" => [
            [
              "source" => "data",
              "property" => "id",
            ],
            [
              "source" => "value",
              "value" => $this->pool->getSiteId(),
            ],
          ],
        ],
        [
          "operator" => "!=",
          "values" => [
            [
              "source" => "data",
              "property" => "base_url",
            ],
            [
              "source" => "value",
              "value" => self::getBaseUrl(),
            ],
          ],
        ],
      ],
    ];

    $condition = json_encode($condition);

    $url = sprintf('%s/api_unify-api_unify-instance-0_1?condition=%s',
      $url,
      $condition
    );
    $response = $this->client->get($url);
    $body = json_decode($response->getBody(), TRUE);

    return $body['total_number_of_items'] > 0;
  }

  /**
   * @inheritdoc
   */
  public function prepareBatch() {
    $url = $this->pool->getBackendUrl();

    if (strlen($this->pool->getSiteId()) > PoolForm::siteIdMaxLength) {
      throw new \Exception(t('The site id of pool ' . $this->pool->id() . ' is having more then ' . PoolForm::siteIdMaxLength . ' characters. This is not allowed due to backend limitations and will result in an exception when it is trying to be exported.'));
    }

    $this->remove(TRUE);

    $operations = [];

    // Create "drupal" API entity.
    $operations[] = [$url . '/api_unify-api_unify-api-0_1', [
      'json' => [
        'id' => 'drupal-' . SyncCorePoolExport::CUSTOM_API_VERSION,
        'name' => 'drupal',
        'version' => SyncCorePoolExport::CUSTOM_API_VERSION,
      ],
    ],
    ];

    // Create the child entity.
    $operations[] = [$url . '/api_unify-api_unify-api-0_1', [
      'json' => [
        'id' => $this->pool->id . '-' . SyncCorePoolExport::CUSTOM_API_VERSION,
        'name' => $this->pool->label(),
        'version' => SyncCorePoolExport::CUSTOM_API_VERSION,
        'parent_id' => 'drupal-' . SyncCorePoolExport::CUSTOM_API_VERSION,
      ],
    ],
    ];

    // Create the instance entity.
    $operations[] = [$url . '/api_unify-api_unify-instance-0_1', [
      'json' => [
        'id' => $this->pool->getSiteId(),
        'base_url' => static::getBaseUrl(),
        'api_id' => $this->pool->id . '-' . SyncCorePoolExport::CUSTOM_API_VERSION,
      ],
    ],
    ];

    // Create the preview connection entity.
    $operations[] = [$url . '/api_unify-api_unify-connection-0_1', [
      'json' => [
        'id' => SyncCoreFlowExport::PREVIEW_CONNECTION_ID,
        'name' => 'Drupal preview connection',
        'hash' => static::EXTERNAL_PREVIEW_PATH,
        'usage' => 'EXTERNAL',
        'status' => 'READY',
        'entity_type_id' => SyncCoreFlowExport::PREVIEW_ENTITY_ID,
        'options' => [
          'crud' => [
            'read_list' => [],
          ],
          'static_values' => [],
        ],
      ],
    ],
    ];

    return $operations;
  }

  /**
   *
   */
  public function remove($removedOnly = TRUE) {
    return TRUE;
  }

}

==> cms_content_sync-8.x-1.11.tar.gz: cms_content_sync/src/SyncCorePoolExport.php <==
<?php

namespace Drupal\cms_content_sync;

use Drupal\cms_content_sync\Entity\Pool;
use Drupal\cms_content_sync\Form\PoolForm;
use Drupal\cms_content_sync\Plugin\rest\resource\EntityResource;
use Drupal\cms_content_sync\SyncCore\Storage\ApiStorage;
use Drupal\cms_content_sync\SyncCore\Storage\PreviewEntityStorage;

/**
 *
 */
class SyncCorePoolExport extends SyncCoreExport {

  /**
   * @var \Drupal\cms_content_sync\Entity\Pool
   */
  protected $pool;

  /**
   * SyncCorePoolExport constructor.
   *
   * @param \Drupal\cms_content_sync\Entity\Pool $pool
   *   The pool this exporter is used for.
   */
  public function __construct(Pool $pool) {
    parent::__construct();

    $this->pool = $pool;
  }

  /**
   * Check if another site has already connected to this pool with the same
   * site ID.
   */
  public function siteIdExists() {
    $url = $this->pool->getBackendUrl();

    $condition = [
      "operator" => "and",
      "conditions" => [
        [
          "operator" => "==",
          "values" => [
            [
              "source" => "data",
              "property" => "id",
            ],
            [
              "source" => "value",
              "value" => $this->pool->getSiteId(),
            ],
          ],
        ],
        [
          "operator" => "!=",
          "values" => [
            [
              "source" => "data",
              "property" => "base_url",
            ],
            [
              "source" => "value",
              "value" => EntityResource::getBaseUrl(),
            ],
          ],
        ],
      ],
    ];

    $condition = json_encode($condition);

    $url = sprintf('%s/api_unify-api_unify-instance-0_1?condition=%s',
      $url,
      $condition
    );
    $response = $this->client->get($url);
    $body = json_decode($response->getBody(), TRUE);

    return $body['total_number_of_items'] > 0;
  }

  /**
   * @inheritdoc
   */
  public function prepareBatch() {
    $url = $this->pool->getBackendUrl();

    if (strlen($this->pool->getSiteId()) > PoolForm::siteIdMaxLength) {
      throw new \Exception(t('The site id of pool ' . $this->pool->id() . ' is having more then ' . PoolForm::siteIdMaxLength . ' characters. This is not allowed due to backend limitations and will result in an exception when it is trying to be exported.'));
    }

    $this->remove(TRUE);

    $operations = [];

    // Create "drupal" API entity.
    $operations[] = [$url . '/api_unify-api_unify-api-0_1', [
      'json' => [
        'id' => 'drupal-' . ApiStorage::CUSTOM_API_VERSION,
        'name' => 'drupal',
        'version' => ApiStorage::CUSTOM_API_VERSION,
      ],
    ],
    ];

    // Create the child entity.
    $operations[] = [$url . '/api_unify-api_unify-api-0_1', [
      'json' => [
        'id' => $this->pool->id . '-' . ApiStorage::CUSTOM_API_VERSION,
        'name' => $this->pool->label(),
        'version' => ApiStorage::CUSTOM_API_VERSION,
        'parent_id' => 'drupal-' . ApiStorage::CUSTOM_API_VERSION,
      ],
    ],
    ];

    // Create the instance entity.
    $operations[] = [$url . '/api_unify-api_unify-instance-0_1', [
      'json' => [
        'id' => $this->pool->getSiteId(),
        'base_url' => EntityResource::getBaseUrl(),
        'version' => static::getVersion(),
        'api_id' => $this->pool->id . '-' . ApiStorage::CUSTOM_API_VERSION,
      ],
    ],
    ];

    // Create the preview connection entity.
    $operations[] = [$url . '/api_unify-api_unify-connection-0_1', [
      'json' => [
        'id' => PreviewEntityStorage::PREVIEW_CONNECTION_ID,
        'name' => 'Drupal preview connection',
        'hash' => PreviewEntityStorage::EXTERNAL_PREVIEW_PATH,
        'usage' => 'EXTERNAL',
        'status' => 'READY',
        'entity_type_id' => PreviewEntityStorage::PREVIEW_ENTITY_ID,
        'options' => [
          'crud' => [
            'read_list' => [],
          ],
          'static_values' => [],
        ],
      ],
    ],
    ];

    return $operations;
  }

  /**
   *
   */
  public function remove($removedOnly = TRUE) {
    return TRUE;
  }

}
